/// <reference types="react" />
import { Node as InnerNode } from '@alilc/lowcode-designer';
import { CompositeValue, NodeSchema, TransformStage } from '@alilc/lowcode-types';
import Prop from './prop';
import Props from './props';
import DocumentModel from './document-model';
import NodeChildren from './node-children';
import ComponentMeta from './component-meta';
import { documentSymbol, nodeSymbol } from './symbols';
export default class Node {
    private readonly [documentSymbol];
    private readonly [nodeSymbol];
    private _id;
    constructor(node: InnerNode);
    static create(node: InnerNode | null | undefined): any;
    /**
     * 节点 id
     */
    get id(): string;
    /**
     * set id
     */
    set id(id: string);
    /**
     * 节点标题
     */
    get title(): string | import("react").ReactElement<any, string | ((props: any) => import("react").ReactElement<any, any>) | (new (props: any) => import("react").Component<any, any, any>)> | import("@alilc/lowcode-types").I18nData;
    /**
     * 是否为「容器型」节点
     */
    get isContainer(): boolean;
    /**
     * 是否为根节点
     */
    get isRoot(): boolean;
    /**
     * 是否为空节点（无 children 或者 children 为空）
     */
    get isEmpty(): boolean;
    /**
     * 是否为 Page 节点
     */
    get isPage(): boolean;
    /**
     * 是否为 Component 节点
     */
    get isComponent(): boolean;
    /**
     * 是否为「模态框」节点
     */
    get isModal(): boolean;
    /**
     * 是否为插槽节点
     */
    get isSlot(): boolean;
    /**
     * 是否为父类/分支节点
     */
    get isParental(): boolean;
    /**
     * 是否为叶子节点
     */
    get isLeaf(): boolean;
    /**
     * judge if it is a node or not
     */
    get isNode(): boolean;
    /**
     * 下标
     */
    get index(): number;
    /**
     * 图标
     */
    get icon(): any;
    /**
     * 节点所在树的层级深度，根节点深度为 0
     */
    get zLevel(): number;
    /**
     * 节点 componentName
     */
    get componentName(): string;
    /**
     * 节点的物料元数据
     */
    get componentMeta(): ComponentMeta;
    /**
     * 获取节点所属的文档模型对象
     * @returns
     */
    get document(): DocumentModel;
    /**
     * 获取当前节点的前一个兄弟节点
     * @returns
     */
    get prevSibling(): Node | null;
    /**
     * 获取当前节点的后一个兄弟节点
     * @returns
     */
    get nextSibling(): Node | null;
    /**
     * 获取当前节点的父亲节点
     * @returns
     */
    get parent(): Node | null;
    /**
     * 获取当前节点的孩子节点模型
     * @returns
     */
    get children(): NodeChildren;
    /**
     * 节点上挂载的插槽节点们
     */
    get slots(): Node[];
    /**
     * 当前节点为插槽节点时，返回节点对应的属性实例
     */
    get slotFor(): Prop;
    /**
     * 返回节点的属性集
     */
    get props(): Props;
    /**
     * 返回节点的属性集
     */
    get propsData(): import("@alilc/lowcode-types").CompositeObject | import("@alilc/lowcode-types").PropsList;
    /**
     * 获取符合搭建协议-节点 schema 结构
     */
    get schema(): any;
    /**
     * @deprecated use .children instead
     */
    getChildren(): NodeChildren;
    /**
     * 获取节点实例对应的 dom 节点
     */
    getDOMNode(): any;
    /**
     * 执行新增、删除、排序等操作
     * @param remover
     * @param adder
     * @param sorter
     */
    mergeChildren(remover: (node: Node, idx: number) => boolean, adder: (children: Node[]) => any, sorter: (firstNode: Node, secondNode: Node) => number): void;
    /**
     * 返回节点的尺寸、位置信息
     * @returns
     */
    getRect(): DOMRect;
    /**
     * 是否有挂载插槽节点
     * @returns
     */
    hasSlots(): boolean;
    /**
     * 是否设定了渲染条件
     * @returns
     */
    hasCondition(): boolean;
    /**
     * 是否设定了循环数据
     * @returns
     */
    hasLoop(): boolean;
    getVisible(): boolean;
    isConditionalVisible(): boolean;
    /**
     * @deprecated use .props instead
     */
    getProps(): Props;
    contains(node: Node): boolean;
    /**
     * 获取指定 path 的属性模型实例
     * @param path 属性路径，支持 a / a.b / a.0 等格式
     * @returns
     */
    getProp(path: string): Prop | null;
    /**
     * 获取指定 path 的属性模型实例值
     * @param path 属性路径，支持 a / a.b / a.0 等格式
     * @returns
     */
    getPropValue(path: string): CompositeValue;
    /**
     * 获取指定 path 的属性模型实例，
     *  注：导出时，不同于普通属性，该属性并不挂载在 props 之下，而是与 props 同级
     * @param path 属性路径，支持 a / a.b / a.0 等格式
     * @returns
     */
    getExtraProp(path: string): Prop | null;
    /**
     * 获取指定 path 的属性模型实例，
     *  注：导出时，不同于普通属性，该属性并不挂载在 props 之下，而是与 props 同级
     * @param path 属性路径，支持 a / a.b / a.0 等格式
     * @returns
     */
    getExtraPropValue(path: string): CompositeValue;
    /**
     * 设置指定 path 的属性模型实例值
     * @param path 属性路径，支持 a / a.b / a.0 等格式
     * @param value 值
     * @returns
     */
    setPropValue(path: string, value: CompositeValue): void;
    /**
     * 设置指定 path 的属性模型实例值
     * @param path 属性路径，支持 a / a.b / a.0 等格式
     * @param value 值
     * @returns
     */
    setExtraPropValue(path: string, value: CompositeValue): void;
    /**
     * 导入节点数据
     * @param data
     */
    importSchema(data: NodeSchema): void;
    /**
     * 导出节点数据
     * @param stage
     * @param options
     * @returns
     */
    exportSchema(stage?: TransformStage, options?: any): NodeSchema;
    /**
     * 在指定位置之前插入一个节点
     * @param node
     * @param ref
     * @param useMutator
     */
    insertBefore(node: Node, ref?: Node | undefined, useMutator?: boolean): void;
    /**
     * 在指定位置之后插入一个节点
     * @param node
     * @param ref
     * @param useMutator
     */
    insertAfter(node: Node, ref?: Node | undefined, useMutator?: boolean): void;
    /**
     * 替换指定节点
     * @param node 待替换的子节点
     * @param data 用作替换的节点对象或者节点描述
     * @returns
     */
    replaceChild(node: Node, data: any): any;
    /**
     * 将当前节点替换成指定节点描述
     * @param schema
     */
    replaceWith(schema: NodeSchema): void;
    /**
     * 选中当前节点实例
     */
    select(): void;
    /**
     * 设置悬停态
     * @param flag
     */
    hover(flag?: boolean): void;
    /**
     * 删除当前节点实例
     */
    remove(): void;
}
