import { SettingField, ISetValueOptions } from '@alilc/lowcode-designer';
import { CompositeValue, FieldConfig } from '@alilc/lowcode-types';
import { settingPropEntrySymbol } from './symbols';
import Node from './node';
export default class SettingPropEntry {
    private readonly [settingPropEntrySymbol];
    constructor(prop: SettingField);
    static create(prop: SettingField): SettingPropEntry;
    /**
     * 获取设置属性的 id
     */
    get id(): string;
    /**
     * 获取设置属性的 name
     */
    get name(): string | number;
    /**
     * 获取设置属性的 key
     */
    get key(): string | number;
    /**
     * 获取设置属性的 path
     */
    get path(): (string | number)[];
    /**
     * 获取设置属性的 title
     */
    get title(): import("@alilc/lowcode-types").TitleContent;
    /**
     * 获取设置属性的 setter
     */
    get setter(): import("@alilc/lowcode-types").SetterType;
    /**
     * 获取设置属性的 extraProps
     */
    get extraProps(): import("@alilc/lowcode-types").FieldExtraProps;
    /**
     * 获取设置属性对应的节点实例
     */
    get node(): Node | null;
    /**
     * 获取设置属性的父设置属性
     */
    get parent(): SettingPropEntry;
    /**
     * 是否是 SettingField 实例
     */
    get isSettingField(): boolean;
    /**
     * 设置 key 值
     * @param key
     */
    setKey(key: string | number): void;
    /**
     * @deprecated use .node instead
     */
    getNode(): Node;
    /**
     * @deprecated use .parent instead
     */
    getParent(): SettingPropEntry;
    /**
     * 设置值
     * @param val 值
     */
    setValue(val: CompositeValue, extraOptions?: ISetValueOptions): void;
    /**
     * 设置子级属性值
     * @param propName 子属性名
     * @param value 值
     */
    setPropValue(propName: string | number, value: any): void;
    /**
     * 清空指定属性值
     * @param propName
     */
    clearPropValue(propName: string | number): void;
    /**
     * 获取配置的默认值
     * @returns
     */
    getDefaultValue(): any;
    /**
     * 获取值
     * @returns
     */
    getValue(): any;
    /**
     * 获取子级属性值
     * @param propName 子属性名
     * @returns
     */
    getPropValue(propName: string | number): any;
    /**
     * 获取设置属性集
     * @returns
     */
    getProps(): any;
    /**
     * 是否绑定了变量
     * @returns
     */
    isUseVariable(): boolean;
    /**
     * 设置绑定变量
     * @param flag
     */
    setUseVariable(flag: boolean): void;
    /**
     * 创建一个设置 field 实例
     * @param config
     * @returns
     */
    createField(config: FieldConfig): SettingPropEntry;
    /**
     * 获取值，当为变量时，返回 mock
     * @returns
     */
    getMockOrValue(): any;
    /**
     * 销毁当前 field 实例
     */
    purge(): void;
    /**
     * 移除当前 field 实例
     */
    remove(): void;
    /**
     * 设置 autorun
     * @param action
     * @returns
     */
    onEffect(action: () => void): () => void;
    /**
     * 返回 shell 模型，兼容某些场景下 field 已经是 shell field 了
     * @returns
     */
    internalToShellPropEntry(): this;
}
